OC.L10N.register(
    "spreed",
    {
    "None" : "គ្មាន",
    "User" : "User",
    "Disabled" : "បាន​បិទ",
    "Users" : "អ្នកប្រើ",
    "Name" : "ឈ្មោះ",
    "Saved" : "បាន​រក្សាទុក",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "ក្រុ",
    "Error" : "កំហុស",
    "Password protect" : "ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Back" : "ត្រឡប់ក្រោយ",
    "Close" : "បិទ",
    "Reply" : "ឆ្លើយតប",
    "Today" : "ថ្ងៃ​នេះ",
    "guest" : "ភ្ញៀវ",
    "Add users or groups" : "Add users or groups",
    "Settings" : "ការកំណត់",
    "Edit" : "កែប្រែ",
    "Share link" : "Share link",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "The password is wrong. Try again." : "ពាក្យ​សម្ងាត់​ខុស​ហើយ។ ព្យាយាម​ម្ដង​ទៀត។",
    "Password" : "ពាក្យសម្ងាត់",
    "Cancel" : "បោះបង់",
    "Change password" : "ប្តូរ​ពាក្យសម្ងាត់",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Send" : "ផ្ញើ",
    "Share" : "ចែក​រំលែក",
    "Error while sharing" : "កំហុស​ពេល​ចែក​រំលែក",
    "Contacts" : "ទំនាក់​ទំនង"
},
"nplurals=1; plural=0;");
